==> whoami_1.2.20101005-2.tar.gz: whoami-1.2.20101005/src/Control.h <==
#ifndef CONTROL_H
#define CONTROL_H

/*
  This file is part of "WhoAmI" - A "Guess whats on the photo" riddle game.
  Copyright (C) 2007  Tim Teulings

  This library is free software; you can redistribute it and/or
  modify it under the terms of the GNU Lesser General Public
  License as published by the Free Software Foundation; either
  version 2.1 of the License, or (at your option) any later version.

  This library is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  Lesser General Public License for more details.

  You should have received a copy of the GNU Lesser General Public
  License along with this library; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA
*/

#include <vector>

#include <Lum/Images/Image.h>

#include <Lum/Model/Boolean.h>

#include <Lum/Object.h>

class Control : public Lum::Object
{
private:
  Lum::Images::ImageRef  image;
  std::vector<bool>      plateState;
  Lum::Model::BooleanRef showAll;

public:
  Control();
  ~Control();

  void SetImage(Lum::Images::Image *image);

  Lum::Model::Boolean* GetShowAll();

  void CalcSize();
  void Draw(Lum::OS::DrawInfo* draw,
            int x, int y, size_t w, size_t h);

  bool HandleMouseEvent(const Lum::OS::MouseEvent& event);

  void Resync(Lum::Base::Model* model, const Lum::Base::ResyncMsg& msg);
};

#endif

==> whoami_1.3.20101220-2.tar.gz: whoami-1.3.20101220/src/Control.h <==
#ifndef CONTROL_H
#define CONTROL_H

/*
  This file is part of "WhoAmI" - A "Guess whats on the photo" riddle game.
  Copyright (C) 2007  Tim Teulings

  This library is free software; you can redistribute it and/or
  modify it under the terms of the GNU Lesser General Public
  License as published by the Free Software Foundation; either
  version 2.1 of the License, or (at your option) any later version.

  This library is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  Lesser General Public License for more details.

  You should have received a copy of the GNU Lesser General Public
  License along with this library; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA
*/

#include <vector>

#include <Lum/Images/Image.h>

#include <Lum/Model/Boolean.h>

#include <Lum/Object.h>

class ImageModel : public Lum::Base::Model
{
private:
  Lum::Images::ImageRef  image;

public:
  bool IsNull() const;

  void Set(Lum::Images::Image *image);
  Lum::Images::Image* Get() const;

  void Clear();
};

typedef Lum::Base::Reference<ImageModel> ImageModelRef;

class Control : public Lum::Control
{
private:
  ImageModelRef          model;
  std::vector<bool>      plateState;
  Lum::Model::BooleanRef showAll;

public:
  Control();
  ~Control();

  bool SetModel(Lum::Base::Model* model);

  Lum::Model::Boolean* GetShowAll();

  void CalcSize();
  void Draw(Lum::OS::DrawInfo* draw,
            int x, int y, size_t w, size_t h);

  bool HandleMouseEvent(const Lum::OS::MouseEvent& event);

  void Resync(Lum::Base::Model* model, const Lum::Base::ResyncMsg& msg);
};

#endif
